DerivedRankBasedMetric
======================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: DerivedRankBasedMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DerivedRankBasedMetric.needs_candidates

   .. rubric:: Methods Summary

   .. autosummary::

      ~DerivedRankBasedMetric.__call__
      ~DerivedRankBasedMetric.adjust
      ~DerivedRankBasedMetric.expected_value
      ~DerivedRankBasedMetric.get_coefficients
      ~DerivedRankBasedMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: needs_candidates

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: get_coefficients
   .. automethod:: variance
